==> kurzaj-0.5.0.tar.gz: kurzaj-0.5.0/kurzaj/main.py <==
identificator = ["secretphrase"]

class kurzajfunctions:
    def getbmi():
        return 16

    def say(thing):
        print(f'kurzaj: {thing}')

    def zajebidentifikator():
        print("successfully jewed")
        return identificator

    def wpierdolidentifikator(iden):
        if iden == identificator:
            return True
    def monologskrypy():
        print("- Jak to jest być skrybą? Dobrze? Moim zdaniem to nie ma tak, że dobrze albo że nie dobrze. Gdybym miał powiedzieć, co cenię w życiu najbardziej, powiedziałbym, że ludzi. Ekhm... Ludzi, którzy podali mi pomocną dłoń, kiedy sobie nie radziłem, kiedy byłem sam. I co ciekawe, to właśnie przypadkowe spotkania wpływają na nasze życie. Chodzi o to, że kiedy wyznaje się pewne wartości, nawet pozornie uniwersalne, bywa, że nie znajduje się zrozumienia, które by tak rzec, które pomaga się nam rozwijać. Ja miałem szczęście, by tak rzec, ponieważ je znalazłem. I dziękuję życiu. Dziękuję mu, życie to śpiew, życie to taniec, życie to miłość. Wielu ludzi pyta mnie o to samo, ale jak ty to robisz?, skąd czerpiesz tę radość? A ja odpowiadam, że to proste, to umiłowanie życia, to właśnie ono sprawia, że dzisiaj na przykład buduję maszyny, a jutro... kto wie, dlaczego by nie, oddam się pracy społecznej i będę ot, choćby sadzić... znaczy... marchew.")
    def bios():
        from types import SimpleNamespace

        table = SimpleNamespace(
            power_managment=SimpleNamespace(
                fanspeed = "1",
                autopowerup = "yes",
                wlan=False
            )
        )


def kurzaj():
    return kurzajfunctions

==> kurzaj-0.6.0.tar.gz: kurzaj-0.6.0/kurzaj/main.py <==
identificator = ["secretphrase"]
from PIL import Image
import os
import importlib.resources
import webbrowser
class kurzaj:
    def getbmi():
        return 16

    def say(thing):
        print(f'kurzaj: {thing}')

    def zajebidentifikator():
        print("successfully jewed")
        return identificator

    def wpierdolidentifikator(iden):
        if iden == identificator:
            return True
    def monologskryby():
        print("- Jak to jest być skrybą? Dobrze? Moim zdaniem to nie ma tak, że dobrze albo że nie dobrze. Gdybym miał powiedzieć, co cenię w życiu najbardziej, powiedziałbym, że ludzi. Ekhm... Ludzi, którzy podali mi pomocną dłoń, kiedy sobie nie radziłem, kiedy byłem sam. I co ciekawe, to właśnie przypadkowe spotkania wpływają na nasze życie. Chodzi o to, że kiedy wyznaje się pewne wartości, nawet pozornie uniwersalne, bywa, że nie znajduje się zrozumienia, które by tak rzec, które pomaga się nam rozwijać. Ja miałem szczęście, by tak rzec, ponieważ je znalazłem. I dziękuję życiu. Dziękuję mu, życie to śpiew, życie to taniec, życie to miłość. Wielu ludzi pyta mnie o to samo, ale jak ty to robisz?, skąd czerpiesz tę radość? A ja odpowiadam, że to proste, to umiłowanie życia, to właśnie ono sprawia, że dzisiaj na przykład buduję maszyny, a jutro... kto wie, dlaczego by nie, oddam się pracy społecznej i będę ot, choćby sadzić... znaczy... marchew.")
    def capybara():
        with importlib.resources.open_binary('kurzaj', 'capybara.jpg') as img_file:
            image = Image.open(img_file)
            return image
    def showcapybara():
        with importlib.resources.open_binary('kurzaj', 'capybara.jpg') as img_file:
            image = Image.open(img_file)
            image.show()
    def togif(image):
        return image.save("togif.gif","GIF")
    def r6femaleavatars():
        webbrowser.open("https://www.roblox.com/games/106201290955067/CUTE-R6-Female-Outfits")
